<rtflowfile version="1.0">
   <block name="Pid" folder="Standard\Dynamic\" width="80" height="96">
      <resize constrainprop="false" allow="true"/>
      <instancename show="true" position="up"/>
      <blockname show="false" position="down"/>
      <portnames show="true" inside="true"/>
      <graphic class="rect" x1="0" y1="0" x2="80" y2="96">
         <fill fill="true" color="0x00EEEEEE"/>
      </graphic>
      <doc>Computes a control value given a setpoint signal and process signal using a PID algorithm. A PID controller is used to produce a control signal that brings a process signal, typically a sensor signal from a physical system, as close as possible to a given setpoint value. The control signal is connected so that it controls the process (the physical system) that produces the process signal. The parameters kp, ki and kd specify the amount of proportional, integral and derivative gain, respectively, in the resulting control signal. To set these parameters correctly, some knowledge of PID controllers is required. Notice that the PID block reacts instantaneously to changes in the process signal, which means that it is necessary to include a delay (a Pre block) in the model of the process to avoid causality loops when simulating.</doc>
      <port name="process" type="real" x="0" y="16" kind="input" dir="left">
         <doc>The process signal that is to be brought closer to setpoint.</doc>
      </port>
      <port name="setpoint" type="real" x="0" y="32" kind="input" dir="left">
         <doc>The value that the process value should be brought closer to.</doc>
      </port>
      <port name="kp" type="real" x="0" y="48" kind="input" dir="left">
         <doc>The amount of proportional gain in the PID algorithm.</doc>
      </port>
      <port name="ki" type="real" x="0" y="64" kind="input" dir="left">
         <doc>The amount of integral gain in the PID algorithm.</doc>
      </port>
      <port name="kd" type="real" x="0" y="80" kind="input" dir="left">
         <doc>The amount of derivative gain in the PID algorithm.</doc>
      </port>
      <port name="control" type="real" x="80" y="16" kind="output" dir="right">
         <doc>The control signal to control the process.</doc>
      </port>
   </block>
   <schematic width="930" height="602" name="Pid">
      <editor gridsize="16" alignports="true"/>
      <binstance name="process" block="RealInput" x="96" y="64"/>
      <binstance name="control" block="RealOutput" x="528" y="72"/>
      <binstance name="setpoint" block="RealInput" x="96" y="48"/>
      <binstance name="Sub1" block="Sub" x="128" y="48"/>
      <binstance name="Integral1" block="Integral" x="208" y="112"/>
      <binstance name="Derivative1" block="Derivative" x="208" y="176"/>
      <binstance name="Add1" block="Add" x="464" y="64"/>
      <binstance name="Add2" block="Add" x="400" y="56"/>
      <binstance name="Mult1" block="Mult" x="304" y="40"/>
      <binstance name="kp" block="RealInput" x="272" y="40"/>
      <binstance name="Mult2" block="Mult" x="304" y="104"/>
      <binstance name="ki" block="RealInput" x="272" y="104"/>
      <binstance name="Mult3" block="Mult" x="304" y="168"/>
      <binstance name="kd" block="RealInput" x="272" y="168"/>
      <connection name="setpoint" port1="setpoint.o" port2="Sub1.i0">
         <point x="112" y="56"/>
         <point x="130" y="56"/>
      </connection>
      <connection name="process" port1="process.o" port2="Sub1.i1">
         <point x="112" y="72"/>
         <point x="130" y="72"/>
      </connection>
      <connection name="error" port1="Sub1.o" port2="Integral1.i0">
         <point x="160" y="64"/>
         <point x="192" y="64"/>
         <point x="192" y="128"/>
         <point x="208" y="128"/>
      </connection>
      <connection name="error" port1="Sub1.o" port2="Derivative1.i0">
         <point x="160" y="64"/>
         <point x="192" y="64"/>
         <point x="192" y="192"/>
         <point x="208" y="192"/>
      </connection>
      <connection name="pi" port1="Add2.o" port2="Add1.i0">
         <point x="432" y="72"/>
         <point x="466" y="72"/>
      </connection>
      <connection name="control" port1="Add1.o" port2="control.i0">
         <point x="496" y="80"/>
         <point x="528" y="80"/>
      </connection>
      <connection name="p" port1="Mult1.o" port2="Add2.i0">
         <point x="336" y="56"/>
         <point x="369" y="56"/>
         <point x="369" y="64"/>
         <point x="402" y="64"/>
      </connection>
      <connection name="error" port1="Sub1.o" port2="Mult1.i1">
         <point x="160" y="64"/>
         <point x="306" y="64"/>
      </connection>
      <connection name="kp" port1="kp.o" port2="Mult1.i0">
         <point x="288" y="48"/>
         <point x="306" y="48"/>
      </connection>
      <connection name="i" port1="Mult2.o" port2="Add2.i1">
         <point x="336" y="120"/>
         <point x="368" y="120"/>
         <point x="368" y="80"/>
         <point x="402" y="80"/>
      </connection>
      <connection name="integral" port1="Integral1.o" port2="Mult2.i1">
         <point x="240" y="128"/>
         <point x="306" y="128"/>
      </connection>
      <connection name="ki" port1="ki.o" port2="Mult2.i0">
         <point x="288" y="112"/>
         <point x="306" y="112"/>
      </connection>
      <connection name="d" port1="Mult3.o" port2="Add1.i1">
         <point x="336" y="184"/>
         <point x="448" y="184"/>
         <point x="448" y="88"/>
         <point x="466" y="88"/>
      </connection>
      <connection name="derivative" port1="Derivative1.o" port2="Mult3.i1">
         <point x="240" y="192"/>
         <point x="306" y="192"/>
      </connection>
      <connection name="kd" port1="kd.o" port2="Mult3.i0">
         <point x="288" y="176"/>
         <point x="306" y="176"/>
      </connection>
   </schematic>
</rtflowfile>
